@@ -1,13 +1,10 @@
-# $Id: Mapping.pm 85 2009-12-10 19:00:14Z cfaerber $
-
 package Unicode::Stringprep::Mapping;
 
 use strict;
 use utf8;
 use warnings;
-require 5.006_000;
 
-our $VERSION = '1.01';
+our $VERSION = "1.10";
 
 use Unicode::Stringprep::_Common;
 
@@ -2260,8 +2257,6 @@ END
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Unicode::Stringprep::Mapping - Tables from S<RFC 3454>, S<Appendix B>
@@ -2282,17 +2277,17 @@ This module exports nothing.
 
 =head1 AUTHOR
 
-Claus Färber E<lt>CFAERBER@cpan.orgE<gt>
+Claus FE<auml>rber E<lt>CFAERBER@cpan.orgE<gt>
 
 =head1 LICENSE
 
-Copyright © 2007-2008 Claus Färber. All rights reserved.
+Copyright 2007-2009 Claus FE<auml>rber.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Unicode::Stringprep>, S<RFC 3454> L<http://www.ietf.org/rfc/rfc3454.txt>
+L<Unicode::Stringprep>, S<RFC 3454> (L<http://www.ietf.org/rfc/rfc3454.txt>)
 
 =cut
